import unittest
from linkers import *
from ingesters.test_oai_pmh import *
from ingesters.test_rels_ext import *
from rml.test_processor import *
from test_bibcat_funcs import *

if __name__ == '__main__':
    unittest.main()
